@@ -2,16 +2,16 @@
 **ConfigurationPanda provides easy loading and access to the data elements of
 JSON based configuration files.**
 
-It works by finding JSON configuration files within specified locations
-and loads each file onto an object attributes so that program internals
-can easily obtain necessary settings without developers having to
-write routine open() and json.loads() operations.
+It works by finding JSON configuration files within locations specified
+by environment variables loads the contents of each file onto an object
+attribute so that program internals can easily obtain necessary settings
+without developers having to write routine open() and json parsing operations.
 
 It is an opinionated library which attempts to encourage fellow developers to:
 
 1.  Avoid Borg-like single configuration files containing all your
     passwords, settings, etc.  Instead, as each configuration file
-    becomes a namespace on the ZenConfiguration object, the contents of
+    becomes a namespace on the ConfigurationPanda object, the contents of
     that file should be explicitly tied to the namespace.
 
 2.  Avoid hardcoding configuration file paths into your programs.
@@ -56,14 +56,22 @@ You would access the contents of those configuration files like this::
     >>> program_settings.smtp['TestAccount1']['login']
     testaccount1
 
+Or, if you prefer dictionary-style syntax::
+
+    >>> from configuration_panda import ConfigurationPanda
+    >>> program_settings = ConfigurationPanda(['SHARED_CONFIG_FILES'])
+    >>> program_settings['ldap']['primary']['url']
+    ldaps://primaryldap.example.edu:111
+    >>> program_settings['smtp']['TestAccount1']['login']
+    testaccount1
+
 BONUS! Set Environment Variables
 --------------------------------
-ConfigurationPanda will also set additional environment variables for you!
+ConfigurationPanda can also set additional environment variables for you!
 
-If during a scan of the location specified the environment variable
-(sorry, you have to set one yourself), a JSON file is found with the
-name 'environment_variables.json', an attempt will be made to
-create an environment variable from each entry within the JSON file.
+If a JSON file named 'environment_variables.json' is found during
+directory scanning, an attempt will be made to create an environment variable
+from each entry within the JSON file.
 
 For instance::
 
@@ -74,12 +82,12 @@ For instance::
       }
 
 This functionality allows you to dynamically insert environment variables
-at runtime based on a configuration variable rather than having to
-make them a permanent fixture in a .bash_profile or .bash_rc file.
+at runtime rather than having to make them a permanent fixture in a
+.bash_profile or .bash_rc file.
 
 
 """
 
 from configuration_panda import ConfigurationPanda
 
-__version__ = '0.5'
+__version__ = '0.6'
